Welcome to pv_tandem's documentation!
======================================



.. toctree::
   :maxdepth: 1
   :caption: Contents:

   readme
   installation
   usage
   model_basics
   auto_examples/index.rst
   api
   contributing
   authors
   history

    

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
